==> qiho-center-api-1.8.5-sources.jar: com/qiho/center/api/dto/account/BaiqiAccountDto.java <==
package com.qiho.center.api.dto.account;

import java.io.Serializable;

/**
 * Created by sunchangji on 2017/12/7.
 */
public class BaiqiAccountDto implements Serializable {

    private static final long serialVersionUID = -4314484220308941492L;

    /**
     * 主键id
     */
    private Long id;

    /**
     * 手机号
     */
    private String mobile;

    /**
     * 账户名称
     */
    private String account;

    /**
     * 关联id,(account_type=0或1则为商家id,account_typ=2则为代理商id)
     */
    private Long relationId;

    /**
     * 账户类型 @See BaiqiAccountTypeEnum
     */
    private Integer accountType;

    /**
     * 主账号id
     */
    private Long parentId;

    /**
     * 密码
     */
    private String pwd;

    /**
     * 账户状态 @See BaiqiAccountStatusEnum
     */
    private Integer state;

    /**
     * 子账号菜单id集
     */
    private String menuIds;

    public String getMenuIds() {
        return menuIds;
    }

    public void setMenuIds(String menuIds) {
        this.menuIds = menuIds;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public Long getRelationId() {
        return relationId;
    }

    public void setRelationId(Long relationId) {
        this.relationId = relationId;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getPwd() {
        return pwd;
    }

    public void setPwd(String pwd) {
        this.pwd = pwd;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }
}

==> qiho-center-api-2.3.77-20200422.072442-9-sources.jar: com/qiho/center/api/dto/account/BaiqiAccountDto.java <==
package com.qiho.center.api.dto.account;

import java.io.Serializable;
import java.util.List;

/**
 * Created by sunchangji on 2017/12/7.
 */
public class BaiqiAccountDto implements Serializable {

    private static final long serialVersionUID = -4314484220308941492L;

    /**
     * 主键id
     */
    private Long id;

    /**
     * 手机号
     */
    private String mobile;

    /**
     * 账户名称
     */
    private String account;

    /**
     * 账户类型 @See BaiqiAccountTypeEnum
     */
    private Integer accountType;

    /**
     * 主账号id
     */
    private Long parentId;

    /**
     * 密码
     */
    private String pwd;

    /**
     * 账户状态 @See BaiqiAccountStatusEnum
     */
    private Integer state;

    /**
     * 子账号菜单id集
     */
    private String menuIds;

    /**
     * 商家版本
     */
    private String versionSign;

    private List<AccountRelatedDto> relatedDtoList;

    public String getMenuIds() {
        return menuIds;
    }

    public void setMenuIds(String menuIds) {
        this.menuIds = menuIds;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getPwd() {
        return pwd;
    }

    public void setPwd(String pwd) {
        this.pwd = pwd;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public String getVersionSign() {
        return versionSign;
    }

    public void setVersionSign(String versionSign) {
        this.versionSign = versionSign;
    }

    public List<AccountRelatedDto> getRelatedDtoList() {
        return relatedDtoList;
    }

    public void setRelatedDtoList(List<AccountRelatedDto> relatedDtoList) {
        this.relatedDtoList = relatedDtoList;
    }
}
